Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(675)

Unified Diff: runtime/vm/precompiler.cc

Issue 2272793004: Update some switchable call stub names and comments. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: . Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/flow_graph_compiler_x64.cc ('k') | runtime/vm/stub_code.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/precompiler.cc
diff --git a/runtime/vm/precompiler.cc b/runtime/vm/precompiler.cc
index dc2c2d02ca399884ef5c879255003d12dac5507d..4fa23bc72312adc8dd19a3bfe88af5e15cd750bf 100644
--- a/runtime/vm/precompiler.cc
+++ b/runtime/vm/precompiler.cc
@@ -1905,7 +1905,7 @@ void Precompiler::SwitchICCalls() {
// the ic data array instead indirectly through a Function in the ic data
// array. Iterate all the object pools and rewrite the ic data from
// (cid, target function, count) to (cid, target code, entry point), and
// replace the ICLookupThroughFunction stub with ICLookupThroughCode.
class SwitchICCallsVisitor : public FunctionVisitor {
public:
@@ -1934,8 +1934,8 @@ void Precompiler::SwitchICCalls() {
ic_ ^= entry_.raw();
ic_.ResetSwitchable(zone_);
} else if (entry_.raw() ==
- StubCode::ICLookupThroughFunction_entry()->code()) {
- target_code_ = StubCode::ICLookupThroughCode_entry()->code();
+ StubCode::ICCallThroughFunction_entry()->code()) {
+ target_code_ = StubCode::ICCallThroughCode_entry()->code();
pool_.SetObjectAt(i, target_code_);
}
}
@@ -1905,7 +1905,7 @@ void Precompiler::SwitchICCalls() {
// array. Iterate all the object pools and rewrite the ic data from
// (cid, target function, count) to (cid, target code, entry point), and
- // replace the ICLookupThroughFunction stub with ICLookupThroughCode.
+ // replace the ICCallThroughFunction stub with ICCallThroughCode.
class SwitchICCallsVisitor : public FunctionVisitor {
public:
« no previous file with comments | « runtime/vm/flow_graph_compiler_x64.cc ('k') | runtime/vm/stub_code.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698